@@ -17,13 +17,13 @@
  * Boston, MA 02111-1307, USA.
  */
 
+#ifndef __ATK_OBJECT_H__
+#define __ATK_OBJECT_H__
+
 #if defined(ATK_DISABLE_SINGLE_INCLUDES) && !defined (__ATK_H_INSIDE__) && !defined (ATK_COMPILATION)
 #error "Only <atk/atk.h> can be included directly."
 #endif
 
-#ifndef __ATK_OBJECT_H__
-#define __ATK_OBJECT_H__
-
 #include <glib-object.h>
 
 #include <atk/atkversion.h>
@@ -192,14 +192,10 @@ G_BEGIN_DECLS
  * (ATK_ROLE_DESCRIPTION_TERM) followed by one or more values
  * (ATK_ROLE_DESCRIPTION_VALUE). For each list, there should not be
  * more than one group with the same term name. @Since: ATK-2.12
- *@ATK_ROLE_DESCRIPTION_TERM: An object that represents the term, or
- * name, part of a term-description group in a description
- * list. @Since: ATK-2.12
+ *@ATK_ROLE_DESCRIPTION_TERM: An object that represents a term or phrase
+ * with a corresponding definition. @Since: ATK-2.12
  *@ATK_ROLE_DESCRIPTION_VALUE: An object that represents the
- * description, definition or value of a term-description group in a
- * description list. The values within a group are alternatives,
- * meaning that you can have several ATK_ROLE_DESCRIPTION_VALUE for a
- * given ATK_ROLE_DESCRIPTION_TERM. @Since: ATK-2.12
+ * description, definition or value of a term. @Since: ATK-2.12
  *@ATK_ROLE_STATIC: A generic non-container object whose purpose is to display a
  * brief amount of information to the user and whose role is known by the
  * implementor but lacks semantic value for the user. Examples in which
@@ -221,6 +217,7 @@ G_BEGIN_DECLS
  * subscript. @Since: ATK-2.16.
  *@ATK_ROLE_SUPERSCRIPT: An object that contains text that is displayed as a
  * superscript. @Since: ATK-2.16.
+ *@ATK_ROLE_FOOTNOTE: An object that contains the text of a footnote. @Since: ATK-2.26.
  *@ATK_ROLE_LAST_DEFINED: not a valid role, used for finding end of the enumeration
  *
  * Describes the role of an object
@@ -353,6 +350,7 @@ typedef enum
   ATK_ROLE_MATH_ROOT,
   ATK_ROLE_SUBSCRIPT,
   ATK_ROLE_SUPERSCRIPT,
+  ATK_ROLE_FOOTNOTE,
   ATK_ROLE_LAST_DEFINED
 } AtkRole;
 
